@@ -75,6 +75,8 @@ class StrictRedisExtensions(BaseRedisExpires, StrictRedis):
         super(StrictRedisExtensions, self).__init__(*args, **kwargs)
 
     def __str(self, x):
+        if isinstance(x, int):
+            return str(x)
         return x if isinstance(x, basestring) else bytes(x)
 
     def __local_ymd(self, format='%Y-%m-%d'):
@@ -371,7 +373,8 @@ class StrictRedisExtensions(BaseRedisExpires, StrictRedis):
         # Srandmember isn't random enough
         # When number is close to ``the number of elements inside the set``
         memebers = self.srandmember(name, number=number)
-        random.shuffle(memebers)
+        if memebers:
+            random.shuffle(memebers)
         return memebers
 
     # ZSorts(Sorted Sets) Section
